/// <reference types="react" />
import * as PropTypes from "prop-types";
import { AnchorType, CenterType } from "./core-types";
export declare enum ResizeType {
    Left = "resize-left",
    Right = "resize-right",
    Top = "resize-top",
    Bottom = "resize-bottom",
    NW = "resize-nw",
    NE = "resize-ne",
    SW = "resize-sw",
    SE = "resize-se"
}
export interface IReactEvents {
    onClick?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onDoubleClick?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onMouseDown?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onMouseEnter?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onMouseLeave?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onMouseMove?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onTouchStart?: (event: React.TouchEvent<HTMLElement>) => void;
    onTouchMove?: (event: React.TouchEvent<HTMLElement>) => void;
    onTouchEnd?: (event: React.TouchEvent<HTMLElement>) => void;
}
export declare const publicProps: {
    id: PropTypes.Requireable<string>;
    className: PropTypes.Requireable<string>;
    style: PropTypes.Requireable<object>;
    scrollable: PropTypes.Requireable<boolean>;
    trackSize: PropTypes.Requireable<boolean>;
    centerContent: PropTypes.Requireable<CenterType>;
    as: PropTypes.Requireable<string>;
    zIndex: PropTypes.Requireable<number>;
    onClick: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseDown: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseEnter: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseLeave: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseMove: PropTypes.Requireable<(...args: any[]) => any>;
    onTouchStart: PropTypes.Requireable<(...args: any[]) => any>;
    onTouchMove: PropTypes.Requireable<(...args: any[]) => any>;
    onTouchEnd: PropTypes.Requireable<(...args: any[]) => any>;
};
export declare const privateProps: {
    isPositioned: PropTypes.Requireable<boolean>;
    anchorSize: PropTypes.Requireable<string | number>;
    anchor: PropTypes.Requireable<AnchorType>;
    resizable: PropTypes.Requireable<boolean>;
    order: PropTypes.Requireable<number>;
    topMost: PropTypes.Requireable<boolean>;
};
export declare const anchoredProps: {
    size: PropTypes.Validator<string | number>;
    order: PropTypes.Requireable<number>;
};
export declare const resizableProps: {
    handleSize: PropTypes.Requireable<number>;
    overlayHandle: PropTypes.Requireable<boolean>;
    minimumSize: PropTypes.Requireable<number>;
    maximumSize: PropTypes.Requireable<number>;
    onResizeStart: PropTypes.Requireable<(...args: any[]) => any>;
    onResizeEnd: PropTypes.Requireable<(...args: any[]) => any>;
};
export declare const positionedProps: {
    left: PropTypes.Requireable<string | number>;
    top: PropTypes.Requireable<string | number>;
    right: PropTypes.Requireable<string | number>;
    bottom: PropTypes.Requireable<string | number>;
    width: PropTypes.Requireable<string | number>;
    height: PropTypes.Requireable<string | number>;
    resizable: PropTypes.Requireable<boolean>;
};
export declare const allProps: {
    left: PropTypes.Requireable<string | number>;
    top: PropTypes.Requireable<string | number>;
    right: PropTypes.Requireable<string | number>;
    bottom: PropTypes.Requireable<string | number>;
    width: PropTypes.Requireable<string | number>;
    height: PropTypes.Requireable<string | number>;
    resizable: PropTypes.Requireable<boolean>;
    handleSize: PropTypes.Requireable<number>;
    overlayHandle: PropTypes.Requireable<boolean>;
    minimumSize: PropTypes.Requireable<number>;
    maximumSize: PropTypes.Requireable<number>;
    onResizeStart: PropTypes.Requireable<(...args: any[]) => any>;
    onResizeEnd: PropTypes.Requireable<(...args: any[]) => any>;
    isPositioned: PropTypes.Requireable<boolean>;
    anchorSize: PropTypes.Requireable<string | number>;
    anchor: PropTypes.Requireable<AnchorType>;
    order: PropTypes.Requireable<number>;
    topMost: PropTypes.Requireable<boolean>;
    id: PropTypes.Requireable<string>;
    className: PropTypes.Requireable<string>;
    style: PropTypes.Requireable<object>;
    scrollable: PropTypes.Requireable<boolean>;
    trackSize: PropTypes.Requireable<boolean>;
    centerContent: PropTypes.Requireable<CenterType>;
    as: PropTypes.Requireable<string>;
    zIndex: PropTypes.Requireable<number>;
    onClick: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseDown: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseEnter: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseLeave: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseMove: PropTypes.Requireable<(...args: any[]) => any>;
    onTouchStart: PropTypes.Requireable<(...args: any[]) => any>;
    onTouchMove: PropTypes.Requireable<(...args: any[]) => any>;
    onTouchEnd: PropTypes.Requireable<(...args: any[]) => any>;
};
